summary refs log tree commit diff
path: root/arch/cris
diff options
context:
space:
mode:
authorJesper Nilsson <jesper.nilsson@axis.com>2008-02-08 10:44:05 +0100
committerJesper Nilsson <jesper.nilsson@axis.com>2008-02-08 11:16:46 +0100
commiteb090473a71ecd35987542fb733a14cc2023777f (patch)
tree20592b2465499490e8489862ae29b3e2f4126c44 /arch/cris
parent9f68ff9ee9ecae38a3b0bb3b9c4799cded19b27c (diff)
downloadlinux-eb090473a71ecd35987542fb733a14cc2023777f.tar.gz
CRIS v32: Correct spelling of bandwidth in function name.
Diffstat (limited to 'arch/cris')
-rw-r--r--arch/cris/arch-v32/mach-a3/arbiter.c6
-rw-r--r--arch/cris/arch-v32/mach-a3/dma.c2
2 files changed, 4 insertions, 4 deletions
diff --git a/arch/cris/arch-v32/mach-a3/dma.c b/arch/cris/arch-v32/mach-a3/dma.c
index 0c19fede0e65..25f236ef0b81 100644
--- a/arch/cris/arch-v32/mach-a3/dma.c
+++ b/arch/cris/arch-v32/mach-a3/dma.c
@@ -24,7 +24,7 @@ int crisv32_request_dma(unsigned int dmanr, const char *device_id,
 	reg_clkgen_rw_clk_ctrl clk_ctrl;
 	reg_strmux_rw_cfg strmux_cfg;
 
-	if (crisv32_arbiter_allocate_bandwith(dmanr,
+	if (crisv32_arbiter_allocate_bandwidth(dmanr,
 			options & DMA_INT_MEM ? INT_REGION : EXT_REGION,
 			bandwidth))
 		return -ENOMEM;
diff --git a/arch/cris/arch-v32/mach-a3/arbiter.c b/arch/cris/arch-v32/mach-a3/arbiter.c
index b92fd7eed3c4..8b924db71c9a 100644
--- a/arch/cris/arch-v32/mach-a3/arbiter.c
+++ b/arch/cris/arch-v32/mach-a3/arbiter.c
@@ -3,7 +3,7 @@
  * arbiter and sets up arbiter breakpoints.
  *
  * The algorithm first assigns slots to the clients that has specified
  * bandwith (e.g. ethernet) and then the remaining slots are divided
  * on all the active clients.
  *
  * Copyright (c) 2004-2007 Axis Communications AB.
@@ -282,7 +282,7 @@ static void crisv32_arbiter_init(void)
 	REG_WR_INT(marb_bar, regi_marb_bar, rw_l2cache_burst, 3);
 }
 
-int crisv32_arbiter_allocate_bandwith(int client, int region,
+int crisv32_arbiter_allocate_bandwidth(int client, int region,
 				      unsigned long bandwidth)
 {
 	int i;
@@ -324,7 +324,7 @@ int crisv32_arbiter_allocate_bandwith(int client, int region,
 
 	/* Propagate allocation from foo to bar */
 	if (arbiter == 0)
-		crisv32_arbiter_allocate_bandwith(8 << 16,
+		crisv32_arbiter_allocate_bandwidth(8 << 16,
 			EXT_REGION, bandwidth);
 	return 0;
 }
@@ -3,7 +3,7 @@
  *
  * The algorithm first assigns slots to the clients that has specified
- * bandwith (e.g. ethernet) and then the remaining slots are divided
+ * bandwidth (e.g. ethernet) and then the remaining slots are divided
  * on all the active clients.
  *